@@ -10,7 +10,7 @@ class HandlingResponse:
 
     def __init__(self, valid, data=None, error=None, code_error=None):
         if valid and data is None:
-            data = {"status": "ok"}
+            data = {"response": "ok"}
 
         self.data = data
         self.error = error
